#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/9/22 16:23
# @Author  : Adyan
# @File    : H5_TK.py


import asyncio
import time
from pyppeteer.launcher import launch
from faker import Faker
from pyppeteer import launcher

# launcher.DEFAULT_ARGS.remove("--enable-automation")

fake = Faker()


class GetTK:
    def __init__(self, mongo_conn):
        self.mongo_conn = mongo_conn

    async def get_content(self, url):
        browser = await launch(
            {
                'headless': True,
                "args": [
                    "--disable-infobars",
                ],
                "dumpio": True,
                "userDataDir": "",
            }
        )
        page = await browser.newPage()
        await page.setViewport({'width': 1200, 'height': 700})
        # await page.setUserAgent(
        #     'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.97 Safari/537.36')
        # try:
        await page.goto(url, {'timeout': 0})
        # except:
        #     return url
        await page.evaluate(
            '''() =>{ Object.defineProperties(navigator, { webdriver:{ get: () => false } }) }''')
        await page.evaluate('''() =>{ window.navigator.chrome = { runtime: {},  }; }''')
        await page.evaluate(
            '''() =>{ Object.defineProperty(navigator, 'languages', { get: () => ['en-US', 'en'] }); }''')
        await page.evaluate(
            '''() =>{ Object.defineProperty(navigator, 'plugins', { get: () => [1, 2, 3, 4, 5,6], }); }''')
        await asyncio.sleep(2)
        cookie_list = await page.cookies()
        print(cookie_list)
        cookies = {}
        for cookie in cookie_list:
            print(cookie.get("name"))
            if cookie.get("name") == '_m_h5_tk' or cookie.get("name") == '_m_h5_tk_enc':
                cookies[cookie.get("name")] = cookie.get("value")
                cookies['time'] = int(time.time() + 3600)
        self.mongo_conn.update_one({'id': '1'}, cookies)
        await browser.close()

    def headers(self):
        while True:
            user_agent = fake.chrome(
                version_from=63, version_to=80, build_from=999, build_to=3500
            )
            if "Android" in user_agent or "CriOS" in user_agent:
                continue
            else:
                break
        return user_agent

    def start(self):
        url = 'https://detail.1688.com/offer/627056024629.html?clickid=7ff082f5c2214f04a00580fcad6c8d52&sessionid=6947210c01f988d9ad53f73e6ec90f24'
        loop = asyncio.get_event_loop()
        return loop.run_until_complete(self.get_content(url))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/12/6 11:11
# @Author  : Adyan
# @File    : settings.py


from Utils import MongoPerson


class Settings:
    def __init__(self, host, port=None, db=None, table=None):
        if not port:
            port = 27017
        if not db:
            db = 'settings'
        if not table:
            table = 'config'
        config = MongoPerson(
            table, db,
            config={"host": host, "port": port}
        ).find_one()
        config.pop("_id")
        self.config = config



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/12/6 10:32
# @Author  : Adyan
# @File    : index.py


from flask import Flask, request
from flask_cors import CORS
from gevent import monkey
from gevent.pywsgi import WSGIServer
from geventwebsocket.handler import WebSocketHandler

from .cookies import Cookies
from ..config_mongo import settings
from ..Utils import ReidsClient

monkey.patch_all()
app = Flask(__name__)
app.config.update(
    DEBUG=True
)
CORS(app, supports_credentials=True)
set = settings.Settings


# TB_detail
@app.route('/cookie', methods=["post", "get"])
def detail():
    types = request.args.to_dict().get("type")
    host = request.args.to_dict().get("host")
    user = set(host=host).config
    res = ReidsClient({"HOST": host, 'DB': 2}).redis_conn
    ip = request.remote_addr
    if res.exists(ip):
        res.setrange(ip, 0, int(res.get(ip)) + 1)
    else:
        res.set(ip, 0, ex=5400)
    code = int(res.get(ip))
    if int(res.get(ip)) == 0:
        res.set(types, Cookies().taobao_cookies(user.get(types)))
        print(res.get(types))
        return {
            "code": code,
            "data": res.get(types).decode('utf-8'),
        }
    else:
        return {
            "code": code,
            "data": res.get(types).decode('utf-8'),
        }


def start(host, prot):
    """9090"""
    app.run(host=host, port=prot)
    http_server = WSGIServer((host, prot), app, handler_class=WebSocketHandler)
    http_server.serve_forever()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2021/8/2 14:46
# @Author  : Adyan
# @File    : Rabbit_conn.py


import json
import pika


class RabbitClient:
    def __init__(self, queue_name, config):
        """
        :param queue_name:
        :param config: {
            "mq_ip": "ip",
            "mq_port": 30002,
            "mq_virtual_host": "my_vhost",
            "mq_username": "dev",
            "mq_pwd": "zl123456",
            "prefix": ""
            }
        """
        self.queue_name = queue_name
        self.config = config

    def rabbit_conn(self):
        """
        创建连接
        :return:
        """
        user_pwd = pika.PlainCredentials(
            self.config.get("mq_username"),
            self.config.get("mq_pwd")
        )
        params = pika.ConnectionParameters(
            host=self.config.get("mq_ip"),
            port=self.config.get('mq_port'),
            virtual_host=self.config.get("mq_virtual_host"),
            credentials=user_pwd
        )
        self.conn = pika.BlockingConnection(parameters=params)
        self.col = self.conn.channel()
        self.col.queue_declare(
            queue=self.queue_name,
            durable=True
        )

    def push_rabbit(self, item):
        self.rabbit_conn()
        self.col.basic_publish(
            exchange='',
            routing_key=self.queue_name,
            body=json.dumps(item, ensure_ascii=False)
        )

    def get_rabbit(self, fun):
        self.rabbit_conn()
        self.col.queue_declare(self.queue_name, durable=True, passive=True)
        self.col.basic_consume(self.queue_name, fun)
        self.col.start_consuming()
